*******************************************************************************************************
** This is the first do file (out of 2) meant to accompany the QJPS article                          **
** "The Causal Effect of Media-Driven Political Interest on Political Attitudes and Behavior."       **
** The major data source is the Swiss Election  Study's Pooled Dataset for 1971-2003.  The most      **
** recent vesion of this file is available at the following website:                                 **
** http://www2.unil.ch/selects/spip.php?rubrique13&lang=en                                           **
** Notice that you have to order a free copy: http://www2.unil.ch/daris/spip.php?rubrique62&lang=en  **
*******************************************************************************************************

/*Prep for Analysis*/
	clear
	set more off
	set mem 500m

/*Get the data - NOTE: CHANGE THIS TO MATCH HOW YOU SAVE THIS FILE ON YOUR COMPUTER*/
	use "/Users/dmb95/Documents/Research/Media Driven Pol Int/Final Documents/swiss elections 71-03 pooled.dta"

	keep if file<=8 	/*Our Analysis used an early version of the file that ended in the year 2003, if you get the current version you'll need to drop the survey years after 2003 to replicate our results*/

********************
********************
* Preping the data *
********************
********************

/*For years when language of interview isn't recorded, use the linguistic region*/
	replace language=sg1 if year==1987 | year==1991  	/*In these years they didn't record the language the interview was conducted in*/

/*Rename Variables*/
	rename year year_survey
		replace year_survey=2003 if year_survey==.
	rename  intinf3 year
		replace year=year_survey if year==.

	rename intinf2 month
		replace month=10 if year==1979 | year==1987 | year==1995
			/*For years when month of interview isn't recorded, we use the month of the election (October). 
			NOTE: in each case, the codebook for the surveys says that the interviews were done 
			all in a two month period that included the date of the election - October*/

/*Create a variable for the month-year when the survey interview occured*/
	generate surveymonth=ym(year, month)

/*Create CONTROL VARIABLES for analysis*/
	recode sex (-2=.)
	gen married=1 if marital==1
		replace married=0 if marital!=1 & marital!=.
	gen higheduc=0 if educ!=.
		replace higheduc=1 if educ>=5 & educ!=.
	gen protestant=0 if religion!=.
		replace protestant=1 if religion==1
	gen catholic=0 if religion!=.
		replace catholic=1 if religion==2
	gen other_religion=0 if religion!=.
		replace other_religion=1 if religion==3
	gen unemployed=0 if sc1!=.
		replace unemployed=1 if sc1==8
	gen canton=sg2						/*This is the Canton they reside in*/
		replace canton=sg3 if canton==.		/*This is the Canton they are registered to vote in*/

/*The timing of most recent National Swiss eleciton - Used in Figure 1*/
	gen swiss_anyelection_monthssince=month-10			/*With the exception of 1972, 1975, & 1976, citizens are interviewed in either October (the month of a nat'l election) or November (the month after a nat'l election)*/
		replace swiss_any=month+2 if year==1972 & month<=2 	/*For these people, the most recent election was the October 1971 Legislative Election*/
		replace swiss_any=0 if year==1972 & month==3 | year==1972 & month==6 | year==1972 & month==9 | year==1975 & month==12 | year==1976 & month==3 |  year==1976 & month==6 | year==1976 & month==9  	 	/*For these people the most recent election was a national referendum that occurred in the same month*/
		replace swiss_any=1 if year==1972 & month==4 | year==1976 & month==1 | year==1976 & month==4  /*For these people the most recent election was a national referendum that occurred in the previous month*/
		replace swiss_any=2 if year==1972 & month==5 | year==1976 & month==2 | year==1976 & month==5 | year==1976 & month==8  /*For these people the most recent election was a national referendum that occurred 2 months prior*/

/*A dummy variable to control for when a voter is interviewed in the same month of a Swiss election*/
	gen swiss_electionmonth=1 if swiss_any==0	
		replace swiss_electionmonth=0 if swiss_any>=1

/*Create the INDPENDENT VARIABLE - POLITICAL INTEREST*/
	gen polint=abs(pi1-5)	/*This just flips the scale so that increasing values indicate increasing levels of political interest*/

/*Create Variable for CLUSTERING*/
	egen clustervar=concat(file canton) 
		destring clustervar, replace

/*Create/rename the DEPENDENT VARIABLES*/
	rename pid1 pid			     	/*Identifies with a Party*/
	rename pp12c part_votations	      /*How Often the Respondent votes in Referndum Elections*/
		recode part_votations (2=.)
	gen knewallalong=1 if mvd1==1 	/*A Dummy Variable for whether they said they knew who they would vote for all along*/
		replace knewall=0 if mvd1>1 & mvd1!=.

/*Create the INSTRUMENTAL VARIABLE - the term "mpe" is an acronym for "Months since Previous Election"*/
	gen mpe_g=.		/*Months since the previous election in Germany*/
	gen mpe_f=.		/*Months since the previous election in France*/
	gen mpe_i=.		/*Months since the previous election in Italy*/
	
	replace	mpe_g=surveymonth-104	if	year==	1971	/*The German Legislative Election in September 1968*/
	replace	mpe_f=surveymonth-113	if	year==	1971	/*The French Presidential Election in June 1969*/
	replace	mpe_i=surveymonth-100	if	year==	1971	/*The Italian Legislative Election in May 1968*/
	
	replace	mpe_g=surveymonth-104	if	year==	1972	/*The German Legislative Election in September 1968*/
	replace	mpe_f=surveymonth-113	if	year==	1972	/*The French Presidential Election in June 1969*/
	replace	mpe_i=surveymonth-100	if	year==	1972 & month<=3 	/*The Italian Legislative Election in May 1968*/
 	replace	mpe_i=surveymonth-148 	if	year==	1972 & month>3	/*The Italian Legislative Election in May 1972*/
	
	replace	mpe_g=surveymonth-154	if	year==	1975	/*The German Legislative Election in November 1972*/
	replace	mpe_f=surveymonth-172	if	year==	1975	/*The French Presidential Election in May 1974*/
	replace	mpe_i=surveymonth-148	if	year==	1975	/*The Italian Legislative Election in May 1972*/
	
	replace	mpe_g=surveymonth-154	if	year==	1976	/*The German Legislative Election in November 1972*/
	replace	mpe_f=surveymonth-172	if	year==	1976	/*The French Presidential Election in May 1974*/
	replace	mpe_i=surveymonth-148	if	year==	1976 & month <=4  /*The Italian Legislative Election in May 1972*/
	replace	mpe_i=surveymonth-197	if	year==	1976 & month>4	/*The Italian Legislative Election in June 1976*/

	replace	mpe_g=surveymonth-201	if	year==	1979	/*The German Legislative Election in October 1976*/
	replace	mpe_f=surveymonth-218	if	year==	1979	/*The French Legislative Election in March 1978*/
	replace	mpe_i=surveymonth-233	if	year==	1979	/*The Italian Legislative Election in June 1979*/
		
	replace	mpe_g=surveymonth-324	if	year==	1987	/*The German Legislative Election in January 1987*/
	replace	mpe_f=surveymonth-314	if	year==	1987	/*The French Legislative Election in March 1986*/
	replace	mpe_i=surveymonth-329	if	year==	1987	/*The Italian Legislative Election in June 1987*/
	
	replace	mpe_g=surveymonth-371	if	year==	1991	/*The German Legislative Election in December 1990*/
	replace	mpe_f=surveymonth-340	if	year==	1991	/*The French Presidential Election in May 1988*/
	replace	mpe_i=surveymonth-329	if	year==	1991	/*The Italian Legislative Election in June 1987*/
	
	replace	mpe_g=surveymonth-417	if	year==	1995	/*The German Legislative Election in October 1994*/
	replace	mpe_f=surveymonth-424	if	year==	1995	/*The French Presidential Election in May 1995*/
	replace	mpe_i=surveymonth-410	if	year==	1995	/*The Italian Legislative Election in March 1994*/
		
	replace	mpe_g=surveymonth-464	if	year==	1999	/*The German Legislative Election in September 1998*/
	replace	mpe_f=surveymonth-449	if	year==	1999	/*The French Legislative Election in June 1997*/
	replace	mpe_i=surveymonth-435	if	year==	1999	/*The Italian Legislative Election in April 1996*/
	
	replace	mpe_g=surveymonth-512	if	year==	2003	/*The German Legislative Election in September 2002*/
	replace	mpe_f=surveymonth-509	if	year==	2003	/*The French Legislative Election in June 2002*/
	replace	mpe_i=surveymonth-496	if	year==	2003	/*The Italian Legislative Election in May 2001*/
	
	replace mpe_i=1 if mpe_i<=0 /*For the italian speaking swiss that were interviewed during the month before the Italian elections in 1972 and 1976*/

	gen mpe=mpe_g if language==1			/*This is the value of the instrument for German Speakers*/
		replace mpe=mpe_f if language==2	/*This is the value of the instrument for French Speakers*/
		replace mpe=mpe_i if language==3	/*This is the value of the instrument for Italian Speakers*/
	
	gen mpe_log=log(mpe) /*taking the log: under the assumption that the influence of mpe drops fast*/

	gen other_log=log(mpe_f) if language==1 & mpe_f<=mpe_i 		/*This is for the placebo test in Table 2.  It records the most recent election in a country that doesn't match the primary language of the Swiss citizen*/
		replace other_log=log(mpe_i) if language==1 & mpe_i<=mpe_f
		replace other_log=log(mpe_i) if language==2 & mpe_i<=mpe_g
		replace other_log=log(mpe_g) if language==2 & mpe_g<=mpe_i
		replace other_log=log(mpe_f) if language==3 & mpe_f<=mpe_g
		replace other_log=log(mpe_g) if language==3 & mpe_g<=mpe_f

/*Create Variables for the Knowledge Analysis in Table 2*/
	gen combined_knowledge=pk5/4
		replace combined_knowledge=(pk5+pk6)/7 if pk6!=.


********************
********************
*     Figure 1     *
********************
********************

bysort year_survey language: egen iv_ave=mean(mpe_log)
bysort year_survey language: gen a=1 if _n==1
gen symbol="F" if language==2
	replace symbol="G" if language==1
	replace symbol="I" if language==3

/*This is to create the "S"s to go in Figure 1*/
gen swiss_log=log(swiss_any)
	replace swiss_log=0 if swiss_any==0
bysort year_survey: egen swiss_ave=mean(swiss_log)
bysort year_survey: gen a2=1 if _n==1
gen symbol2="S"

twoway (scatter iv_ave year_survey if a==1, msize(zero) msymbol(none) mlabel(symbol) mlabsize(medsmall) mlabposition(0) mlabcolor(black)) (scatter swiss_ave year_survey if a2==1, msize(zero) msymbol(none) mlabel(symbol2) mlabsize(medsmall) mlabposition(0) mlabcolor(black)), ytitle("Log(Months Since Previous Election" "in Neighboring Country)") ylabel(, angle(horizontal)) xtitle(Year) xlabel(1971(4)2003) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) legend(off)


********************
********************
*   Tables 2 & 3   *
********************
********************

/*Table 2, Column 1: First Stage Results*/
	xi: reg polint mpe_log swiss_electionmonth sex age higheduc married protestant catholic other_rel unemployed i.canton [pweight = weight], cluster(clustervar)
		test mpe_log
	
/*Table 2, Column 2: Placebo Test that tests how well election timing in countries that don't share the same language predict political interest.
	The variable "other_log" is the natural log of the number of elections since the most recent election in one of the surrounding
	countries that doesn't share a common language with the region.*/  
	xi: reg polint mpe_log other_log swiss_electionmonth sex age higheduc married protestant catholic other_rel unemployed i.canton [pweight = weight], cluster(clustervar)

/*Table 2, Columns 3-4: The surveys of 1995, 1999, 2003 include questions about pol knowledge (pk1-pk4). 
	Variable pk5 is a knowledge scale that goes from 0 to 4.  We compare how well the instrument predicts
	both political knowledge (pk5) and political interest in years that both questions are asked.*/
	xi: reg combined_knowledge mpe_log swiss_electionmonth sex age higheduc married protestant catholic other_rel unemployed i.canton [pweight = weight] if year==1995| year==1999|year==2003, cluster(clustervar)
	xi: reg polint mpe_log swiss_electionmonth sex age higheduc married protestant catholic other_rel unemployed i.canton [pweight = weight] if year==1995| year==1999| year==2003, cluster(clustervar)

/*Table 3: OLS/Probit  v. IV regressions */
	xi: probit knewallalong polint swiss_electionmonth sex age higheduc married protestant catholic other_rel unemployed i.canton if mpe_log!=. [pweight = weight], cluster(clustervar)
	xi: ivprobit knewallalong swiss_electionmonth sex age higheduc married protestant catholic other_rel unemployed i.canton (polint=mpe_log) [pweight = weight], cluster(clustervar) difficult

	xi: probit pid polint swiss_electionmonth sex age higheduc married protestant catholic other_rel unemployed i.canton if mpe_log!=. [pweight = weight], cluster(clustervar)
	xi: ivprobit pid swiss_electionmonth sex age higheduc married protestant catholic other_rel unemployed i.canton (polint=mpe_log) [pweight = weight], cluster(clustervar) difficult

	xi: reg part_votations polint swiss_electionmonth sex age higheduc married protestant catholic other_rel unemployed i.canton if mpe_log!=. [pweight = weight], cluster(clustervar)
	xi: ivregress 2sls  part_votations swiss_electionmonth sex age higheduc married protestant catholic other_rel unemployed i.canton  (polint=mpe_log) [pweight = weight], cluster(clustervar)

***************************************************************
***************************************************************
*  Table 4 - Actual Turnout in Reference - See second do file *
***************************************************************
***************************************************************


******************************
******************************
/*  Supplementary Appendix  */
******************************
******************************

/* Compositional effects. Number of married and catholic respondents decreases over time in all linguistic regions*/
	by file language, sort: sum sex  higheduc higheduc married protestant catholic other_rel unemployed if language!=. & language!=4 

/*Alternative Coding of Political interest as a binary variable*/
gen highint=0 if polint==1 | polint==2
	replace highint=1 if polint!=. & highint==.
	
	xi: regress highint mpe_log swiss_electionmonth sex age higheduc married protestant catholic other_rel unemployed i.canton [pweight = weight], cluster(clustervar)
		test mpe_log
	xi: ivregress 2sls  part_votations swiss_electionmonth sex age higheduc married protestant catholic other_rel unemployed i.canton (highint=mpe_log) [pweight = weight], cluster(clustervar)
	xi: ivprobit pid swiss_electionmonth sex age higheduc married protestant catholic other_rel unemployed i.canton (highint=mpe_log) [pweight = weight], cluster(clustervar) difficult
	xi: ivprobit knewallalong swiss_electionmonth sex age higheduc married protestant catholic other_rel unemployed i.canton (highint=mpe_log) [pweight = weight], cluster(clustervar) difficult

/* Results without covariates. (Results are stable) */
	/*First Stage*/
	xi: reg polint mpe_log, cluster(clustervar)	
	/*Second Stage*/
	xi: ivregress 2sls part_votations (polint=mpe_log) [pweight = weight], cluster(clustervar)
	xi: ivprobit pid (polint=mpe_log) [pweight = weight], cluster(clustervar)
	xi: ivprobit knewallalong (polint=mpe_log) [pweight = weight], cluster(clustervar) difficult


***************************
***************************
* IV Sensitivity Analyses *
***************************
***************************

/* This is the results for completing the sensitivity analysis suggested by Conley, Hansen and Rossi (2008)that we refer to at the end of Section 2. In the cod the term "omega_eta" indicates how much of a direct effect 
the instrument would need to have on the outcome before the results would no longer be informative about the hypothesis.
Also note that we use linear probability models for all three outcomes.  Finally, the ado files were downloaded from 
Christian Hansen's webiste: http://faculty.chicagobooth.edu/christian.hansen/research/ */


/*PARTICIPATION IN REFERENDA outcome*/
/* N(0,0.019^2) */
#delimit;
matrix omega_eta = J(36,36,0);
matrix omega_eta[1,1] = .019^2; 
matrix mu_eta = J(36,1,0);
/* Obtain local to zero approximation estimates using prior specified above */
xi: ltz omega_eta mu_eta part_votations (polint swiss_electionmonth sex age higheduc married protestant catholic 
other_rel unemployed i.canton = mpe_log swiss_electionmonth sex age higheduc married protestant catholic 
other_rel unemployed i.canton) , level(.95) cluster(clustervar);
/* Obtain bounds */
xi: ivregress 2sls part_votations swiss_electionmonth sex age higheduc married protestant catholic other_rel unemployed i.canton (polint=mpe_log) [pweight = weight], cluster(clustervar);
xi: uci part_votations (polint swiss_electionmonth sex age higheduc married protestant catholic 
other_rel unemployed i.canton = mpe_log swiss_electionmonth sex age higheduc married protestant catholic 
other_rel unemployed i.canton) , inst(mpe_log) g1min(-.025) g1max(.025) grid(2) level(.95) cluster(clustervar);

/*PARTY ID outcome*/
/* N(0,.025^2) */
matrix omega_eta4 = J(36,36,0);
matrix omega_eta4[1,1] = .03^2;
matrix mu_eta4 = J(36,1,0);
/* Obtain local to zero approximation estimates using prior specified above */
xi: ltz omega_eta4 mu_eta4 pid (polint swiss_electionmonth sex age higheduc married protestant catholic 
other_rel unemployed i.canton = mpe_log swiss_electionmonth sex age higheduc married protestant catholic 
other_rel unemployed i.canton) , level(.95) cluster(clustervar);
/* Obtain bounds */
xi: ivregress 2sls pid swiss_electionmonth sex age higheduc married protestant catholic other_rel unemployed i.canton (polint=mpe_log) [pweight = weight], cluster(clustervar);
xi: uci pid (polint swiss_electionmonth sex age higheduc married protestant catholic 
other_rel unemployed i.canton = mpe_log swiss_electionmonth sex age higheduc married protestant catholic 
other_rel unemployed i.canton) , inst(mpe_log) g1min(-.041) g1max(.041) grid(2) level(.95) cluster(clustervar);

#delimit;
/*KNEW ALL ALONG outcome*/
/* N(0,.025^2) */
matrix omega_eta5 = J(36,36,0);
matrix omega_eta5[1,1] = .029^2;
matrix mu_eta5= J(36,1,0);
/* Obtain local to zero approximation estimates using prior specified above */
xi: ltz omega_eta5 mu_eta5 knewallalong (polint swiss_electionmonth sex age higheduc married protestant catholic 
other_rel unemployed i.canton = mpe_log swiss_electionmonth sex age higheduc married protestant catholic 
other_rel unemployed i.canton) , level(.95) cluster(clustervar);
/* Obtain bounds */
xi: ivregress 2sls knew sex age higheduc married protestant catholic other_rel unemployed i.canton (polint=mpe_log) [pweight = weight], cluster(clustervar);
xi: uci knewallalong (polint swiss_electionmonth sex age higheduc married protestant catholic 
other_rel unemployed i.canton = mpe_log swiss_electionmonth sex age higheduc married protestant catholic 
other_rel unemployed i.canton) , inst(mpe_log) g1min(-.027) g1max(.027) grid(2) level(.95) cluster(clustervar);
